# Creating a Custom Matrix Report
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/creating-custom-matrix-report?version=CLOUD#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/creating-custom-matrix-report?version=CLOUD#prerequisites)
  * [Step 1: Navigate to the Project Directory](https://help.sap.com/docs/leanix/ea/creating-custom-matrix-report?version=CLOUD#step-1:-navigate-to-the-project-directory)
  * [Step 2: Create a Custom Report Module](https://help.sap.com/docs/leanix/ea/creating-custom-matrix-report?version=CLOUD#step-2:-create-a-custom-report-module)
  * [Step 3: Import Facets into the Main Module](https://help.sap.com/docs/leanix/ea/creating-custom-matrix-report?version=CLOUD#step-3:-import-facets-into-the-main-module)
  * [Step 4: Update HTML Content](https://help.sap.com/docs/leanix/ea/creating-custom-matrix-report?version=CLOUD#step-4:-update-html-content)
  * [Step 5: Start the Development Server](https://help.sap.com/docs/leanix/ea/creating-custom-matrix-report?version=CLOUD#step-5:-start-the-development-server)
  * [Summary](https://help.sap.com/docs/leanix/ea/creating-custom-matrix-report?version=CLOUD#summary)


Learn how to create a custom matrix report showing the lifecycle phases of application fact sheets.
